@@ -119,7 +119,6 @@ class ExtraClaimsOIDCAuthenticationBackend(OIDCAuthenticationBackend):
 
         # Validate the token
         payload = self.verify_token(id_token, nonce=nonce)
-        keycloak_user_id = payload.get("sub")
 
         if payload:
             self.store_tokens(
@@ -128,8 +127,7 @@ class ExtraClaimsOIDCAuthenticationBackend(OIDCAuthenticationBackend):
                 id_token,
                 refresh_token,
                 expires_in,
-                refresh_expires_in,
-                keycloak_user_id
+                refresh_expires_in
             )
 
             try:
@@ -156,8 +154,7 @@ class ExtraClaimsOIDCAuthenticationBackend(OIDCAuthenticationBackend):
         id_token: str,
         refresh_token: str,
         expires_in: int,
-        refresh_expires_in: int,
-        keycloak_user_id: str,
+        refresh_expires_in: int
     ):
         """Store OIDC tokens.
 
@@ -167,11 +164,9 @@ class ExtraClaimsOIDCAuthenticationBackend(OIDCAuthenticationBackend):
         :param refresh_token: The refresh token.
         :param expires_in: The access token expiration time.
         :param refresh_expires_in: The refresh token expiration time.
-        :param keycloak_user_id: The keycloak user id.
         """
         session = self.request.session
         session["keycloak_session_id"] = keycloak_session_id
-        session["keycloak_user_id"] = keycloak_user_id
 
         if not session.get("old_keycloak_session_id"):
             session["old_keycloak_session_id"] = keycloak_session_id
