@@ -20,7 +20,7 @@ from dnoticias_services.authentication.keycloak import get_user_keycloak_info
 from mozilla_django_oidc.utils import absolutify, import_from_settings
 from mozilla_django_oidc.auth import OIDCAuthenticationBackend
 
-from .utils import set_cookie, SessionManager
+from .utils import set_cookie, get_cookie_configuration, SessionManager
 from . import cookies_consts
 
 User = get_user_model()
@@ -92,6 +92,21 @@ class BaseAuthMiddleware:
 
         return exempt_patterns
 
+    @cached_property
+    def exempt_session_url_patterns(self) -> set:
+        """Urls that should not be processed by this middleware in DCS password update session
+
+        :return: set of regular expressions
+        :rtype: set"""
+        exempt_patterns = set()
+        patterns = getattr(settings, "SESSION_CHECK_EXEMPT_URLS", [])
+
+        for url_pattern in patterns:
+            if isinstance(url_pattern, Pattern):
+                exempt_patterns.add(url_pattern)
+
+        return exempt_patterns 
+
     def _is_processable(self, request: HttpRequest):
         pass
 
@@ -206,41 +221,33 @@ class TokenMiddleware(BaseAuthMiddleware, MiddlewareMixin):
 
         :param request: The request to be processed
         :param response: The response to the request
-        :returns: The response to the request
+        :returns:returns: The response to the request
         :rtype: HttpResponse
         """
 
         if self._is_processable(request):
+            oidc_login_cookie = cookies_consts.LOGIN_NEXT
             keycloak_session_cookie = cookies_consts.KC_SESSION_ID
             access_token_cookie = cookies_consts.ACCESS_TOKEN
             access_token_expiration_cookie = cookies_consts.ACCESS_TOKEN_EXPIRATION
             old_keycloak_session_cookie = cookies_consts.OLD_KC_SESSION_ID
-            keycloak_user_id_cookie = cookies_consts.KC_USER_ID
 
+            oidc_login_value = request.session.get('oidc_login_next', '')
             keycloak_session_value = request.session.get('keycloak_session_id', {})
             access_token_value = request.session.get('oidc_access_token', '')
             access_token_expiration_value = request.session.get('oidc_access_token_expiration', '')
             old_keycloak_session_value = request.session.get('old_keycloak_session_id', '')
-            keycloak_user_id = request.session.get('keycloak_user_id', '')
 
-            response = set_cookie(access_token_cookie, access_token_value, response, http_only=True)
+            response = set_cookie(oidc_login_cookie, oidc_login_value, response)
+            response = set_cookie(access_token_cookie, access_token_value, response)
             response = set_cookie(
                 access_token_expiration_cookie,
                 access_token_expiration_value,
-                response,
-                http_only=True
+                response
             )
 
-            if keycloak_user_id:
-                response = set_cookie(keycloak_user_id_cookie, keycloak_user_id, response)
-
             if keycloak_session_value:
-                response = set_cookie(
-                    keycloak_session_cookie,
-                    keycloak_session_value,
-                    response,
-                    http_only=True
-                )
+                response = set_cookie(keycloak_session_cookie, keycloak_session_value, response)
 
             if old_keycloak_session_value != keycloak_session_value:
                 request.session["old_keycloak_session_value"] = keycloak_session_value
@@ -256,11 +263,6 @@ class TokenMiddleware(BaseAuthMiddleware, MiddlewareMixin):
                 request.session.save()
 
             if old_keycloak_session_value:
-                response = set_cookie(
-                    old_keycloak_session_cookie,
-                    old_keycloak_session_value,
-                    response,
-                    http_only=True
-                )
+                response = set_cookie(old_keycloak_session_cookie, old_keycloak_session_value, response)
 
         return response
