@@ -6,6 +6,14 @@ from django import template
 
 register = template.Library()
 
+def _rebuild_query_list(params: dict) -> dict:
+    """Used to avoid returning ?param=['1'] if the GET param is single valued"""
+    for key, param in params.items():
+            if len(param) == 1:
+                params[key] = param[0]
+
+    return params
+
 
 def _build_url(reverse_url: str, context: dict, next_url: Union[str, None], to_root: bool) -> str:
     """
@@ -23,8 +31,9 @@ def _build_url(reverse_url: str, context: dict, next_url: Union[str, None], to_r
         absolute_url = urlparse(request.build_absolute_uri())
         url = urlparse(next_url)
 
-        params = parse_qs(url.query)
-        absolute_params = parse_qs(absolute_url.query)
+        params = _rebuild_query_list(parse_qs(url.query))
+        absolute_params = _rebuild_query_list(parse_qs(absolute_url.query))
+
         absolute_params.update(params)
 
         next_url = request.build_absolute_uri(request.path)
