@@ -23,14 +23,4 @@ urlpatterns = [
         views.ApplicationDataView.as_view(),
         name="application-data"
     ),
-    path(
-        "endpoints/logout/",
-        views.DnoticiasLogoutEndpointView.as_view(),
-        name="dnoticias-logout-endpoint"
-    ),
-    path(
-        "verify/",
-        views.SendVerificationEmailView.as_view(),
-        name="dnoticias-auth-verify"
-    )
 ]
