@@ -1,22 +1,19 @@
 import logging
 import json
 from datetime import datetime, timedelta
-from typing import Optional
+from typing import Optional, Union
 from time import time
 
 from django.http import HttpResponse, HttpResponseRedirect
-from django.core.exceptions import SuspiciousOperation
 from django import VERSION as DJANGO_VERSION
 from django.utils.encoding import force_str
 from django.conf import settings
 
 import requests
-import redis
-from mozilla_django_oidc.contrib.drf import OIDCAuthentication
+
 from dnoticias_services.authentication.keycloak import (
     delete_user_session as delete_session_kc,
     get_user_keycloak_info,
-    user_is_verified
 )
 from redis_sessions.session import RedisServer
 from keycloak import KeycloakDeleteError
@@ -28,7 +25,27 @@ from . import cookies_consts
 logger = logging.getLogger(__name__)
 
 
-INTERNAL_CLIENTS_KEY_HEADER = 'X-Internal-Clients-Key'
+# DEPRECATED
+def get_cookie_equivalency(
+    name: Optional[str] = None,
+    all_names: Optional[bool] = False
+) -> Union[dict, str]:
+    """Returns the cookie equivalency for the given name
+
+    :param name: The name of the cookie
+    :param all_names: If True, returns all the cookie equivalencies
+    :return: The cookie equivalency or a dict with all the equivalencies
+    :rtype: Union[dict, str]
+    """
+    EQUIVALENCY = {
+        'oidc_login_next': 'dn_oln',
+        'keycloak_session_id': 'dn_ksi',
+        'user_context_used': 'dn_ucu',
+        'oidc_access_token': 'dn_oat',
+        'oidc_access_token_expiration': 'dn_oate',
+    }
+
+    return EQUIVALENCY.get(name) if not all_names else EQUIVALENCY
 
 
 def get_cookie_configuration(
@@ -59,8 +76,7 @@ def set_cookie(
     name: str,
     value: str,
     response: HttpResponse,
-    expiration_minutes: Optional[int]=None,
-    http_only: Optional[bool]=False,
+    expiration_minutes: Optional[int]=None
 ) -> HttpResponse:
     """Generates all the cookies needed on another clients to process the user
 
@@ -68,12 +84,11 @@ def set_cookie(
     :param value: The value of the cookie
     :param response: The response object
     :param expiration_minutes: The expiration minutes of the cookie
-    :param http_only: If True, the cookie is only accessible by the server
     :return: The response object
     :rtype: HttpResponse
     """
     # Extra kwargs used in set_cookie
-    extra_data = get_cookie_configuration(expiration_minutes, http_only)
+    extra_data = get_cookie_configuration(expiration_minutes=expiration_minutes)
     response.set_cookie(name, value, **extra_data)
 
     return response
@@ -210,16 +225,14 @@ class SessionManager:
         information = self.get_information()
         return len(information.keys()) if information else 0
 
-    def get_user_session_data(self) -> int:
+    def get_user_max_sessions(self) -> int:
         user_attributes = get_user_keycloak_info(self.email)
         max_sessions = user_attributes.get("attributes", {}).get("max_sessions", 2)
-        is_staff = user_attributes.get("attributes", {}).get("is_staff", False)
-        is_superuser = user_attributes.get("attributes", {}).get("is_superuser", False)
 
         if type(max_sessions) == list:
             max_sessions = max_sessions[0]
 
-        return int(max_sessions), is_staff or is_superuser
+        return int(max_sessions)
 
     def notify_deleted_session(self, session_id: str):
         headers = {'Authorization': f'Api-Key {settings.SUBSCRIPTION_SERVICE_ACCOUNT_API_KEY}'}
@@ -264,13 +277,10 @@ class SessionManager:
         if event == self.LOGIN:
             logger.debug("Handling login event for %s", self.email)
             self.update_session_information()
-            max_sessions, is_staff = self.get_user_session_data()
 
-            if not is_staff and self.get_session_count() > max_sessions:
+            if self.get_session_count() > self.get_user_max_sessions():
                 logger.debug("Deleting old session for %s", self.email)
                 self.delete_oldest_session()
-            elif is_staff:
-                logger.debug("Staff user %s logged in, not deleting session", self.email)
 
         elif event == self.LOGOUT:
             logger.debug("Handling logout event for %s", self.email)
@@ -325,69 +335,3 @@ class SessionManager:
                 success = False
 
         return success
-
-
-class CookieOIDCAuthentication(OIDCAuthentication):
-    def get_access_token(self, request):
-        cookie = request.COOKIES.get(cookies_consts.ACCESS_TOKEN)
-        return cookie if cookie and cookie not in ("undefined", "null", "") else None
-
-
-class VerificationManager:
-    def __init__(self):
-        logger.info("[Verification|Redis] Verification init")
-        self._redis = redis.Redis(
-            host=settings.SESSION_REDIS_HOST,
-            port=settings.SESSION_REDIS_PORT,
-            password=settings.SESSION_REDIS_PASSWORD,
-            db=settings.REDIS_VERIFICATION_DATABASE   
-        )
-
-    def get_redis_key(self, email: str) -> str:
-        return f"verification:{email}"
-
-    def set_user_verified(
-        self,
-        email: str,
-        session: dict = None,
-        verified: bool = True
-    ):
-        if session:
-            session["email_verified"] = verified
-
-        self._redis.set(self.get_redis_key(email), 1 if verified else 0)
-
-    def user_is_verified(self, email: str, session: dict = None) -> bool:
-        is_verified_keycloak = None
-        is_verified_session = None
-        is_verified_cache = self._redis.get(self.get_redis_key(email))
-
-        if isinstance(is_verified_cache, bytes):
-            is_verified_cache = bool(int(is_verified_cache))
-
-        if session:
-            is_verified_session = session.get("email_verified")
-
-        if not is_verified_session and is_verified_cache and session:
-            session["email_verified"] = is_verified_cache
-
-        if is_verified_cache is None and is_verified_session is None:
-            try:
-                is_verified_keycloak = user_is_verified(email)
-            except SuspiciousOperation:
-                logger.exception("Failed to verify user %s", email)
-                is_verified_keycloak = False
-
-            if is_verified_keycloak:
-                self.set_user_verified(email, session)
-
-        is_verified = bool(is_verified_cache or is_verified_session or is_verified_keycloak)
-        self.set_user_verified(email, session, is_verified)
-
-        return is_verified
-
-    def flush(self):
-        self._redis.flushdb()
-
-
-verification_manager = VerificationManager()
