@@ -1,37 +1,31 @@
 import logging
-from urllib.parse import urljoin
 from time import time
 
 from django.views.decorators.clickjacking import xframe_options_exempt
 from django.core.exceptions import SuspiciousOperation
 from django.http.response import HttpResponseRedirect
-from django.utils.module_loading import import_string
 from django.views.decorators.csrf import csrf_exempt
 from django.utils.decorators import method_decorator
+from django.views.generic import View, FormView
 from django.http import Http404, HttpResponse
-from django.utils.http import urlencode
-from django.views.generic import View
+from django.urls import reverse_lazy
 from django.shortcuts import render
 from django.conf import settings
-from django.urls import reverse
 from django.contrib import auth
 
-import requests
-from dnoticias_services.authentication.keycloak import user_is_verified, send_verification_email
 from mozilla_django_oidc.views import (
     OIDCLogoutView,
     OIDCAuthenticationCallbackView
 )
 
+from .forms import PasswordRecoveryDCSForm
 from . import cookies_consts
 from .utils import (
-    INTERNAL_CLIENTS_KEY_HEADER,
     SessionManager,
     set_cookie,
     delete_oidc_cookies,
     delete_user_sessions,
     refresh_keycloak_token,
-    verification_manager,
 )
 
 logger = logging.getLogger(__name__)
@@ -83,34 +77,6 @@ class DnoticiasOIDCLogoutView(OIDCLogoutView):
             logger.warning("No BASE_URL configured! Using / as default...")
 
         return logout_url + next_url if logout_url else base_url
-    
-    def trigger_logout_endpoints(self, request):
-        """
-        This function was created to trigger the logout endpoints of the other services
-        """
-        logout_endpoints = self.get_settings('AUTH_INTERNAL_CLIENTS_URLS', None)
-        logout_endpoints_keys = self.get_settings('AUTH_INTERNAL_CLIENTS_SECRETS', None)
-        logout_path = self.get_settings('AUTH_LOGOUT_ENDOPINT_PATH', '/auth/endpoints/logout/')
-
-        logger.debug("Logout endpoints: %s", logout_endpoints)
-        if logout_endpoints:
-            for index, endpoint in enumerate(logout_endpoints):
-                endpoint = urljoin(endpoint, logout_path)
-
-                try:
-                    response = requests.post(
-                        endpoint,
-                        data={
-                            "email": request.user.email,
-                        },
-                        headers={
-                            INTERNAL_CLIENTS_KEY_HEADER: logout_endpoints_keys[index],
-                        },
-                        cookies=request.COOKIES,
-                    )
-                    response.raise_for_status()
-                except Exception as e:
-                    logger.exception("Error while trying to logout from %s", endpoint)
 
     def post(self, request) -> HttpResponseRedirect:
         """
@@ -131,38 +97,11 @@ class DnoticiasOIDCLogoutView(OIDCLogoutView):
         )
 
         delete_user_sessions(keycloak_session_id)
-        self.trigger_logout_endpoints(request)
         super().post(request)
 
         return delete_oidc_cookies(self.redirect_url, request.COOKIES)
 
 
-class DnoticiasLogoutEndpointView(View):
-    @method_decorator(csrf_exempt)
-    def dispatch(self, request, *args, **kwargs):
-        return super().dispatch(request, *args, **kwargs)
-
-    def post(self, request):
-        """This endpoint is used to logout from the other services"""
-        logout_function = getattr(settings, "AUTH_LOGOUT_ENDPOINT_FUNCTION", None)
-        internal_secret = getattr(settings, "AUTH_INTERNAL_CLIENT_SECRET", None)
-
-        if not internal_secret or not logout_function:
-            raise Http404()
-
-        if request.headers.get(INTERNAL_CLIENTS_KEY_HEADER) != internal_secret:
-            raise HttpResponse(status=403)
-
-        email = request.POST.get("email")
-        cookies = request.COOKIES
-
-        if logout_function:
-            logout_function = import_string(logout_function)
-            logout_function(email, cookies)
-
-        return HttpResponse(status=204)
-
-
 class DnoticiasOIDCAuthenticationCallbackView(OIDCAuthenticationCallbackView):
     def login_failure(self, delete_cookies: bool = False) -> HttpResponse:
         response = HttpResponseRedirect(self.failure_url)
@@ -182,12 +121,11 @@ class DnoticiasOIDCAuthenticationCallbackView(OIDCAuthenticationCallbackView):
         access_token_expiration_cookie = cookies_consts.ACCESS_TOKEN_EXPIRATION
         access_token_cookie = cookies_consts.ACCESS_TOKEN
 
-        response = set_cookie(access_token_cookie, access_token, response, http_only=True)
+        response = set_cookie(access_token_cookie, access_token, response)
         response = set_cookie(
             access_token_expiration_cookie,
             access_token_expiration,
-            response,
-            http_only=True
+            response
         )
 
         return response
@@ -223,19 +161,8 @@ class DnoticiasOIDCAuthenticationCallbackView(OIDCAuthenticationCallbackView):
             # State is the key, the value is a dictionary with the Nonce in the "nonce" field.
             state = request.GET.get('state')
             if state not in request.session['oidc_states']:
-                msg = 'OIDC callback state not found in session `oidc_states`, redirecting...'
-                logger.error(msg)
-                next_url = self.success_url
-                logger.debug("Redirecting to %s", next_url)
-
-                if next_url:
-                    return HttpResponseRedirect(
-                        f"{reverse('oidc_authentication_init')}?{urlencode({'next': next_url})}"
-                    )
-                else:
-                    return self.login_failure()
-
-                # raise SuspiciousOperation(msg)
+                msg = 'OIDC callback state not found in session `oidc_states`!'
+                raise SuspiciousOperation(msg)
 
             # Get the nonce from the dictionary for further processing and delete the entry to
             # prevent replay attacks.
@@ -270,17 +197,8 @@ class DnoticiasOIDCAuthenticationCallbackView(OIDCAuthenticationCallbackView):
             self.user = auth.authenticate(**kwargs)
 
             if self.user and self.user.is_active:
-                # is_verified = user_is_verified(self.user.email)
-                # verification_manager.set_user_verified(
-                #     self.user.email,
-                #     request.session,
-                #     is_verified
-                # )
-                # request.session.save()
-
                 access_token_expiration = request.session["oidc_access_token_expiration"]
                 access_token = request.session["oidc_access_token"]
-
                 return self.login_success(access_token_expiration, access_token)
 
         return self.login_failure(delete_cookies=True)
@@ -301,15 +219,36 @@ class ApplicationDataView(View):
         return render(request, self.template_name, locals())
 
 
-class SendVerificationEmailView(View):
-    @method_decorator(csrf_exempt)
+class PasswordRecoveryDCSFormView(FormView):
+    template_name = "authentication/password-recovery.html"
+    form_class = PasswordRecoveryDCSForm
+
     def dispatch(self, request, *args, **kwargs):
+        if not request.session.get("migration_email"):
+            raise Http404()
+
         return super().dispatch(request, *args, **kwargs)
 
-    def post(self, request, *args, **kwargs):
-        if not request.user.is_authenticated:
-            return HttpResponse(status=404)
+    def get_success_url(self):
+        next_url = self.request.session.get("migration_next_url")
+        login_url = reverse_lazy("oidc_authentication_init")
+        return f"{login_url}?next_url={next_url}"
 
-        response = send_verification_email(request.user.email)
+    def get_context_data(self, **kwargs) -> dict:
+        context = super().get_context_data(**kwargs)
+        next_url = self.request.session.get('migration_next_url')
+        reset_url = settings.OIDC_RESET_PASSWORD_URL
+        context["password_recovery_url"] = f"{reset_url}?next={next_url}"
+        return context
 
-        return HttpResponse(status=response.status_code)
+    def get_form_kwargs(self) -> dict:
+        kwargs = super().get_form_kwargs()
+        kwargs["email"] = self.request.session.get("migration_email")
+        return kwargs
+
+    def form_valid(self, form):
+        form.save()
+        return super().form_valid(form)
+
+    def form_invalid(self, form):
+        return super().form_invalid(form)
